==> hs-gio-0.12.3_1.tbz: lib/ghc-7.4.1/cabal/gio-0.12.3/register.sh <==
#!/bin/sh
echo 'name: gio
version: 0.12.3
id: gio-0.12.3-d4fa99730a97194e714a9725fe2ce6eb

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the GIO.
description: GIO is striving to provide a modern, easy-to-use VFS API that sits at the right level in the library stack.
             The goal is to overcome the shortcomings of GnomeVFS and provide an API that is
             so good that developers prefer it over raw POSIX calls.
             Among other things that means using GObject.
             It also means not cloning the POSIX API, but providing higher-level, document-centric interfaces.
category: System
author: Peter Gavin, Andy Stewart
exposed: True
exposed-modules: System.GIO System.GIO.Enums System.GIO.Types
                 System.GIO.Async.AsyncResult System.GIO.Async.Cancellable
                 System.GIO.File.AppInfo System.GIO.File.ContentType
                 System.GIO.File.FileAttribute System.GIO.File.File
                 System.GIO.File.FileEnumerator System.GIO.File.FileInfo
                 System.GIO.File.FileMonitor System.GIO.File.IOError
                 System.GIO.File.MountOperation System.GIO.Icons.Emblem
                 System.GIO.Icons.EmblemedIcon System.GIO.Icons.FileIcon
                 System.GIO.Icons.Icon System.GIO.Icons.ThemedIcon
                 System.GIO.Volumes.Drive System.GIO.Volumes.Mount
                 System.GIO.Volumes.Volume System.GIO.Volumes.VolumeMonitor
hidden-modules: System.GIO.Signals
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/gio-0.12.3
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/gio-0.12.3
              /usr/local/lib
hs-libraries: HSgio-0.12.3
extra-libraries: gio-2.0 gobject-2.0 gthread-2.0 gmodule-2.0
                 glib-2.0
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/glib-2.0
includes:
depends: array-0.4.0.0-59d1cc0e7979167b002f021942d60f46
         base-4.5.0.0-3459bca6d8e46666b517e8bb2e033728
         bytestring-0.9.2.1-6ff76798e80a342ff74a1c8bcb3f4124
         containers-0.4.2.1-cfc6420ecc2194c9ed977b06bdfd9e69
         glib-0.12.3.1-b8fe1b8554ac9f9afc9af7e353ede55d
         mtl-2.1.1-801101765c9185fec3b8dbd5355f5550
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/gio-0.12.3/html/gio.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/gio-0.12.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-gio-0.12.4_1.tbz: lib/ghc-7.4.2/cabal/gio-0.12.4/register.sh <==
#!/bin/sh
echo 'name: gio
version: 0.12.4
id: gio-0.12.4-6a3699a85ea9089288fef9bcbf6e90a8

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the GIO.
description: GIO is striving to provide a modern, easy-to-use VFS API that sits at the right level in the library stack.
             The goal is to overcome the shortcomings of GnomeVFS and provide an API that is
             so good that developers prefer it over raw POSIX calls.
             Among other things that means using GObject.
             It also means not cloning the POSIX API, but providing higher-level, document-centric interfaces.
category: System
author: Peter Gavin, Andy Stewart
exposed: True
exposed-modules: System.GIO System.GIO.Enums System.GIO.Types
                 System.GIO.Async.AsyncResult System.GIO.Async.Cancellable
                 System.GIO.File.AppInfo System.GIO.File.ContentType
                 System.GIO.File.FileAttribute System.GIO.File.File
                 System.GIO.File.FileEnumerator System.GIO.File.FileInfo
                 System.GIO.File.FileMonitor System.GIO.File.IOError
                 System.GIO.File.MountOperation System.GIO.Icons.Emblem
                 System.GIO.Icons.EmblemedIcon System.GIO.Icons.FileIcon
                 System.GIO.Icons.Icon System.GIO.Icons.ThemedIcon
                 System.GIO.Volumes.Drive System.GIO.Volumes.Mount
                 System.GIO.Volumes.Volume System.GIO.Volumes.VolumeMonitor
hidden-modules: System.GIO.Signals
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/gio-0.12.4
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/gio-0.12.4
              /usr/local/lib
hs-libraries: HSgio-0.12.4
extra-libraries: gio-2.0 gobject-2.0 glib-2.0
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/glib-2.0
includes:
depends: array-0.4.0.0-0b6c5ca7e879a14d110ca4c001dd9297
         base-4.5.1.0-f58939ca866a8377999e7a71aa62d1d0
         bytestring-0.9.2.1-4cc8a513193316dfe32ba33f47609c9d
         containers-0.4.2.1-75f143aa39a3e77a1ce2300025bdd8ce
         glib-0.12.4-2696509aa1c1a77771da26d8647d44d8
         mtl-2.1.2-02e701f9b1590ee88a0b5b0bd5d93a29
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/gio-0.12.4/html/gio.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/gio-0.12.4/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
